@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -1031,16 +1031,7 @@ double FULLCOND_rj::p_prop(double prop)
 
 //		FULLCOND::outresults();
 
-		 #if defined(MICROSOFT_VISUAL)
-		{
-			number = __min(number, freq.size());
-		}
-		#else
-		{
-			number = min(number, freq.size());
-		}
-		#endif
-
+		number = min(number, freq.size());
 
 		std::sort(freq.begin(), freq.end());
 
