@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -1270,41 +1270,17 @@ double FULLCOND_kriging::outresultsreml(datamatrix & X,datamatrix & Z,
 
   if(mapexisting)
     {
-#if defined(JAVA_OUTPUT_WINDOW)
-    optionsp->out("  Postscript files are stored in files\n");
-    ST::string psfile;
-    psfile = outest.substr(0,outest.length()-4) + ".ps";
-    optionsp->out("  " + psfile + "\n");
-    psfile = outest.substr(0,outest.length()-4) + "_pcatbig" + ".ps";
-    optionsp->out("  " + psfile + "\n");
-    psfile = outest.substr(0,outest.length()-4) + "_pcatsmall" + ".ps";
-    optionsp->out("  " + psfile + "\n");
-    optionsp->out("\n");
-    optionsp->out("  Results may be visualized using method 'drawmap'\n");
-    optionsp->out("  Type for example:\n");
-    optionsp->out("  objectname.drawmap " + ST::inttostring(plotpos) + "\n");
-#else
     optionsp->out("  Results may be visualized using the R function 'drawmap' \n");
-#endif
     optionsp->out("\n");
     }
   else if(onedim)
     {
-    #if defined(JAVA_OUTPUT_WINDOW)
-    optionsp->out("  Postscript file is stored in file\n");
-    ST::string psfile = outest.substr(0,outest.length()-4) + ".ps";
-    optionsp->out("  " + psfile + "\n");
-    optionsp->out("\n");
-    optionsp->out("  Results may be visualized using method 'plotnonp'\n");
-    optionsp->out("  Type for example: objectname.plotnonp " + ST::inttostring(plotpos) + "\n");
-    #else
     optionsp->out("  Results may be visualized using the R function 'plotnonp'\n");
     ST::string doublebackslash = "/";
     ST::string spluspath = outest.insert_string_char('\\',doublebackslash);
     optionsp->out("  Type for example:\n");
     optionsp->out("  plotnonp(\"" + spluspath + "\")");
     optionsp->out("\n");
-    #endif
     optionsp->out("\n");
     }
   else
